@@ -2,8 +2,9 @@
 use fil_actor_multisig::{Actor as MultisigActor, ConstructorParams, Method, SIGNERS_MAX};
 use fil_actors_runtime::test_utils::*;
 use fil_actors_runtime::{INIT_ACTOR_ADDR, SYSTEM_ACTOR_ADDR};
-use fvm_ipld_encoding::RawBytes;
 use fvm_shared::address::Address;
+// use fvm_shared::econ::TokenAmount;
+use fvm_shared::encoding::RawBytes;
 use fvm_shared::error::ExitCode;
 // use serde::Serialize;
 
@@ -29,7 +30,7 @@ fn test_construction_fail_to_construct_multisig_actor_with_0_signers() {
     rt.set_caller(*INIT_ACTOR_CODE_ID, *INIT_ACTOR_ADDR);
 
     expect_abort(
-        ExitCode::USR_ILLEGAL_ARGUMENT,
+        ExitCode::ErrIllegalArgument,
         rt.call::<MultisigActor>(
             Method::Constructor as u64,
             &RawBytes::serialize(&zero_signer_params).unwrap(),
@@ -56,7 +57,7 @@ fn test_construction_fail_to_construct_multisig_with_more_than_max_signers() {
     rt.expect_validate_caller_addr(vec![*INIT_ACTOR_ADDR]);
     rt.set_caller(*INIT_ACTOR_CODE_ID, *INIT_ACTOR_ADDR);
     expect_abort(
-        ExitCode::USR_ILLEGAL_ARGUMENT,
+        ExitCode::ErrIllegalArgument,
         rt.call::<MultisigActor>(
             Method::Constructor as u64,
             &RawBytes::serialize(&over_max_signers_params).unwrap(),
